@@ -21,16 +21,22 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <iostream.h>
+#include <fstream.h>
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "fileutil.h"
+#include "my_string.h"
 
-static void file_error(char *progname, const char *error, char *file);
-static void internal_error(char *progname, const char *error);
+static void file_error(const char *error, char *file);
+static void internal_error(const char *error);
 
 #define OUTPUT_EXTENSION ".html"
 
 char *
-read_file(char *progname, char *fileName)
+read_file(char *fileName)
 {
   FILE *file;
   char *buffer = 0;
@@ -40,27 +46,27 @@ read_file(char *progname, char *fileName)
   // Windows system: when we fread, the number of char read can be
   // less then char_count, and thus we'd get an error...
   if ( (file = fopen(fileName,"rb") ) == 0 )	// The file does not exist :(
-    file_error (progname, "Error operning", fileName);
+    file_error ("Error operning", fileName);
   else
     {
       // let's go to the end of the file...
       if (fseek (file, 0, SEEK_END) != 0)
-        file_error (progname, "Error positioning", fileName);
+        file_error ("Error positioning", fileName);
 
       // ...to read the dimension
       char_count = ftell (file);
       if (char_count < 0)
-        file_error (progname, "Error reading position", fileName);
+        file_error ("Error reading position", fileName);
 
       buffer = (char *) malloc (char_count +1);
       if (! buffer)
-        internal_error (progname, "Memory allocation failed");
+        internal_error ("Memory allocation failed");
 
       // let's go back to the start
       rewind (file);
 
       if (fread ((void *) buffer, 1, char_count, file) < (size_t) char_count)
-        file_error (progname, "read error", fileName);
+        file_error ("read error", fileName);
       buffer[char_count] = '\0';
 
       fclose (file);
@@ -70,16 +76,16 @@ read_file(char *progname, char *fileName)
 }
 
 void
-file_error(char *progname, const char *error, char *file)
+file_error(const char *error, char *file)
 {
-  cerr << progname << ": " << error << ", file " << file << endl;
+  cerr << PACKAGE << ": " << error << ", file " << file << endl;
   exit (1);
 }
 
 void
-internal_error(char *progname, const char *error)
+internal_error(const char *error)
 {
-  cerr << progname << ": Internal error: " << error << endl;
+  cerr << PACKAGE << ": Internal error: " << error << endl;
   exit (1);
 }
 
@@ -135,3 +141,36 @@ createOutputFileName( char *inputFileName, char *outputDir )
 
   return outputFileName ;
 }
+
+unsigned int
+get_line_count(char *file_name)
+{
+  ifstream input (file_name);
+
+  if (! input)
+    file_error ("Error opening", file_name);
+
+  unsigned int count = get_line_count (input);
+
+  input.close ();
+
+  return count;
+}
+
+unsigned int
+get_line_count(istream &input)
+{
+  unsigned int count = 0;
+  string line;
+
+  while (true)
+    {
+      getline (input, line);
+      if (! input.eof ())
+        ++count;
+      else
+        break;
+    }
+
+  return count;
+}
