@@ -18,8 +18,4 @@ extern TextGenerator *SymbolGenerator ;
 extern TextGenerator *FunctionGenerator ;
 extern TextGenerator *CBracketGenerator ;
 
-extern void createGenerators(CharTranslator *, int) ;
-extern void createXhtmlGenerators(CharTranslator *, int) ;
-extern void createGeneratorsForCSS(CharTranslator *, int) ;
-
 #endif
