@@ -48,6 +48,8 @@ extern int prolog_scanner_lex() ;
 extern int perl_scanner_lex() ;
 extern int php3_scanner_lex() ;
 extern int python_scanner_lex() ;
+extern int flex_scanner_lex() ;
+extern int changelog_scanner_lex() ;
 
 extern int tabSpaces; // FIXME
 
@@ -63,7 +65,7 @@ processFile( char *source_language, char *output_format,
              short entire_doc, char *cssUrl )
 {
   FILE *in = 0;
-  short deleteOStream = 1 ;
+  bool deleteOStream = false ;
 
   if ( outputFileName ) {
     sout = new ofstream(outputFileName) ;
@@ -71,6 +73,7 @@ processFile( char *source_language, char *output_format,
       cerr << "Error in creating " << outputFileName << " for output" << endl ;
       exit(1) ;
     }
+    deleteOStream = true;
   }
 
   if (inputFileName)
@@ -110,8 +113,8 @@ processFile( char *source_language, char *output_format,
    */
   if (sout == 0) {
     sout = &cout;
-    deleteOStream = 0 ; // we can't delete cout !!!
   }
+
   if (in == 0) {
     ; /* Well stdin already points to stdin so, .... */
   }
@@ -147,6 +150,10 @@ processFile( char *source_language, char *output_format,
     php3_scanner_lex ();
   else if (strcmp (source_language, "python") == 0)
     python_scanner_lex ();
+  else if (strcmp (source_language, "flex") == 0)
+    flex_scanner_lex ();
+  else if (strcmp (source_language, "changelog") == 0)
+    changelog_scanner_lex ();
   else
     {
       cerr << PACKAGE << ": ";
@@ -247,13 +254,11 @@ void
 print_xtop( char *docTitle, char *cssUrl,
            const char *docHeader, char *inputFileName)
 {
-  if( cssUrl == 0 ) {
-    _generateln( "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">" ) ;
-  }
-  else {
-    _generateln( "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0Transitional//EN\"");
-    _generateln( " \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">");
-  }
+  _generateln 
+    ("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"");
+  _generateln
+    (" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">");
+
   _generateln( "<html>" ) ;
   _generateln( "<head>" ) ;
   _generateln( "<meta http-equiv=\"Content-Type\"" ) ;
