@@ -26,7 +26,7 @@ extern char *inputFileName ; /* what we're reading  */
 extern ostream* sout ;
 
 char *createOutputFileName( char *inputFileName ) ;
-void processFile( char *source_language,
+void processFile( char *source_language, char *output_format,
                   char *inputFileName, char *outputFileName, char *docTitle,
                   const char *docHeader, const char *docFooter,
                   short entire_doc, char *cssUrl ) ;
@@ -35,6 +35,9 @@ void print_cgi_header();
 void print_top( char *docTitle, char *s , const char *docHeader,
                 char *inputFileName) ;
 void print_bottom( const char *docFooter ) ;
+void print_xtop( char *docTitle, char *s , const char *docHeader,
+                char *inputFileName) ;
+void print_xbottom( const char *docFooter ) ;
 void generate( const char *s ) ;
 void generate( const char *s, int start, int end ) ;
 void generateln( const char *s ) ;
@@ -59,7 +62,5 @@ void endString( const char *s ) ;
 
 void startTAG( const char *tag, const char *attr = 0, const char *val = 0 ) ;
 void endTAG( const char *tag ) ;
-void startColor( const char *color ) ;
-void endColor() ;
 
 #endif // _GENFUN_H
