@@ -1,31 +1,12 @@
 #ifndef TAGS_H
 #define TAGS_H
 
-#define QUOTATION_MARK "&quot;"
-#define LESS_THAN "&lt;"
-#define GREATER_THAN "&gt;"
-#define AMPERSAND "&amp;"
-//#define NEWLINE "<br>" for xhtml should be "<br />"
 #define SPACE_CHAR " "
 
-#define FONT_TAG "font"
-#define COLOR_TAG "color"
-#define BOLD_TAG "b"
-#define ITALIC_TAG "i"
-#define UNDERLINE_TAG "u"
-
 #define ISBOLD 0x1
 #define ISITALIC 0x2
 #define ISUNDERLINE 0x4
 
-#define SPAN_TAG "span"
-#define XHTML_BOLD_TAG "font-weight"
-#define XHTML_ITALIC_TAG "font-style"
-#define XHTML_UNDERLINE_TAG "text-decoration"
-#define XHTML_BOLD_VAL "bold"
-#define XHTML_ITALIC_VAL "italic"
-#define XHTML_UNDERLINE_VAL "underline"
-
 #include "colors.h"
 
 #include <iostream.h>
