@@ -80,24 +80,3 @@ TextGenerator::endText( const char *s )
   endTextGeneration() ;
 }
 
-// TextDecorator
-TextDecorator::TextDecorator(TextGenerator *t, CharTranslator *tr) :
-  TextGenerator (tr), decorated (t)
-{
-}
-
-void
-TextDecorator::startTextGeneration()
-{ 
-  startDecorate() ;
-  if ( decorated )
-    decorated->startTextGeneration() ;
-}
-
-void
-TextDecorator::endTextGeneration()
-{ 
-  if ( decorated )
-    decorated->endTextGeneration() ;
-  endDecorate() ;
-}
