@@ -19,10 +19,11 @@
 
 #include <iostream.h>
 
-#include "startapp4html.h"
+#include "startapp.h"
 
 int
 main( int argc, char * argv[] )
 {
-  return startapp4html (argc, argv);
+  StartApp start_app;
+  return start_app.start (argc, argv);
 }
